==> apache-iceberg-0.13.1.tar.gz: apache-iceberg-0.13.1/aliyun/src/test/java/org/apache/iceberg/aliyun/TestAliyunClientFactories.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iceberg.aliyun;

import com.aliyun.oss.OSS;
import java.util.Map;
import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
import org.apache.iceberg.relocated.com.google.common.collect.Maps;
import org.junit.Assert;
import org.junit.Test;

public class TestAliyunClientFactories {

  @Test
  public void testLoadDefault() {
    Assert.assertEquals("Default client should be singleton",
        AliyunClientFactories.defaultFactory(), AliyunClientFactories.defaultFactory());

    AliyunClientFactory defaultFactory = AliyunClientFactories.from(Maps.newHashMap());
    Assert.assertTrue(
        "Should load default when factory impl not configured",
         defaultFactory instanceof AliyunClientFactories.DefaultAliyunClientFactory);
    Assert.assertNull("Should have no Aliyun properties set",
        defaultFactory.aliyunProperties().accessKeyId());

    AliyunClientFactory defaultFactoryWithConfig = AliyunClientFactories.from(
        ImmutableMap.of(AliyunProperties.CLIENT_ACCESS_KEY_ID, "key"));
    Assert.assertTrue(
        "Should load default when factory impl not configured",
        defaultFactoryWithConfig instanceof AliyunClientFactories.DefaultAliyunClientFactory);
    Assert.assertEquals("Should have access key set",
        "key", defaultFactoryWithConfig.aliyunProperties().accessKeyId());
  }

  @Test
  public void testLoadCustom() {
    Map<String, String> properties = Maps.newHashMap();
    properties.put(AliyunProperties.CLIENT_FACTORY, CustomFactory.class.getName());
    Assert.assertTrue(
        "Should load custom class",
        AliyunClientFactories.from(properties) instanceof CustomFactory);
  }

  public static class CustomFactory implements AliyunClientFactory {

    AliyunProperties aliyunProperties;

    public CustomFactory() {
    }

    @Override
    public OSS newOSSClient() {
      return null;
    }

    @Override
    public void initialize(Map<String, String> properties) {
      this.aliyunProperties = new AliyunProperties(properties);
    }

    @Override
    public AliyunProperties aliyunProperties() {
      return aliyunProperties;
    }
  }
}

==> apache-iceberg-1.4.0.tar.gz: apache-iceberg-1.4.0/aliyun/src/test/java/org/apache/iceberg/aliyun/TestAliyunClientFactories.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.aliyun;

import com.aliyun.oss.OSS;
import java.util.Map;
import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
import org.apache.iceberg.relocated.com.google.common.collect.Maps;
import org.junit.Assert;
import org.junit.Test;

public class TestAliyunClientFactories {

  @Test
  public void testLoadDefault() {
    Assert.assertEquals(
        "Default client should be singleton",
        AliyunClientFactories.defaultFactory(),
        AliyunClientFactories.defaultFactory());

    AliyunClientFactory defaultFactory = AliyunClientFactories.from(Maps.newHashMap());
    Assert.assertTrue(
        "Should load default when factory impl not configured",
        defaultFactory instanceof AliyunClientFactories.DefaultAliyunClientFactory);
    Assert.assertNull(
        "Should have no Aliyun properties set", defaultFactory.aliyunProperties().accessKeyId());

    AliyunClientFactory defaultFactoryWithConfig =
        AliyunClientFactories.from(ImmutableMap.of(AliyunProperties.CLIENT_ACCESS_KEY_ID, "key"));
    Assert.assertTrue(
        "Should load default when factory impl not configured",
        defaultFactoryWithConfig instanceof AliyunClientFactories.DefaultAliyunClientFactory);
    Assert.assertEquals(
        "Should have access key set",
        "key",
        defaultFactoryWithConfig.aliyunProperties().accessKeyId());
  }

  @Test
  public void testLoadCustom() {
    Map<String, String> properties = Maps.newHashMap();
    properties.put(AliyunProperties.CLIENT_FACTORY, CustomFactory.class.getName());
    Assert.assertTrue(
        "Should load custom class",
        AliyunClientFactories.from(properties) instanceof CustomFactory);
  }

  public static class CustomFactory implements AliyunClientFactory {

    AliyunProperties aliyunProperties;

    public CustomFactory() {}

    @Override
    public OSS newOSSClient() {
      return null;
    }

    @Override
    public void initialize(Map<String, String> properties) {
      this.aliyunProperties = new AliyunProperties(properties);
    }

    @Override
    public AliyunProperties aliyunProperties() {
      return aliyunProperties;
    }
  }
}
